@@ -320,7 +320,7 @@ evas_object_textgrid_textprop_unref(Evas_Object_Textgrid *o, unsigned int props_
      {
         if (props->info->refcount == 1)
           eina_array_push(&o->glyphs_cleanup,
-                          (void *)((unsigned long)props_index));
+                          (void *)((uintptr_t)props_index));
         else
           {
              Evas_Glyph *glyphs = props->glyphs;
